@@ -1,3 +1,7 @@
 #!/bin/bash
+if [ "`grep \#DEFINES src/src.pro`" == "" ]; then
+    echo "Seems to be disabled already!"
+    exit 1
+fi
 find . -name "*.pro" -exec sed -i "s/TARGET.UID3 = 0x20045CF8/#TARGET.UID3 = 0x20045CF8/g" {} \;
 sed -i "s/#DEFINES += EXPIRATION_DATE/DEFINES += EXPIRATION_DATE/g" ./src/src.pro
