@@ -15,6 +15,7 @@
 #include <QApplication>
 #include <QClipboard>
 #include <math.h>
+#include <QAbstractItemView>
 
 #include "coordinatetool.h"
 #include "pickermanager.h"
@@ -460,6 +461,11 @@ QWidget *CoordinateTool::createWidget(const QString &title) {
   connect(m_cBox, SIGNAL(activated(const QString &)), 
 	  this, SLOT(selectWaypoint(const QString &)));
 
+  m_cBox->view()->setTextElideMode (Qt::ElideRight);
+  QSizePolicy sp1 (QSizePolicy::Ignored, QSizePolicy::Fixed, QSizePolicy::ComboBox);
+  sp1.setHorizontalStretch(2);
+  m_cBox->setSizePolicy(sp1);
+
   m_cBox->addItem(m_cache.description());
 
   foreach(Waypoint wpt, m_cache.waypoints())
