@@ -6,16 +6,18 @@
 #include <QString>
 #include <QList>
 #include <QPainter>
+#include <QRect>
 
 class MapWidget;
 
 class MapBannerEntry : public QObject {
   Q_OBJECT;
  public:
-  enum State { Appearing, Visible, Disappearing, Done };
+  enum State { Waiting, Appearing, Visible, Disappearing, Done };
   MapBannerEntry(MapWidget *, const QString &);
   ~MapBannerEntry();
-  void paint(QPainter *);
+  void paint(QPainter *, bool);
+  bool isDisappearing() const;
 
  private slots:
   void timeout();
@@ -24,14 +26,18 @@ class MapBannerEntry : public QObject {
   void done(MapBannerEntry *);
 
  private:
+  QRect area();
+
   QTimer *m_timer;
   QString m_message;
   State m_state;
   int m_counter;
   MapWidget *m_mapWidget;
+  bool m_important;
+
   static const int STEPS = 10;
   static const int APPEAR = 500;   // (dis-)appears in these msec
-  static const int STAY = 2000;    // stays these msec
+  static const int STAY = 3000;    // stays these msec
 };
 
 class MapBannerEntryList : public QList<MapBannerEntry*> {
