@@ -11,6 +11,8 @@
 
 #include "cache.h"
 #include "iconloader.h"
+#include "locationprovider.h"
+#include "waypointdb.h"
 
 #include "mapoverlay.h"
 #include "mapbanner.h"
@@ -32,9 +34,12 @@ class MapWidget : public QGraphicsGeoMap {
   void paint(QPainter *, const QStyleOptionGraphicsItem *, QWidget * = 0);
   bool hiRez() const;
   void setHiRez(bool);
+  bool hideOwn() const;
+  void setHideOwn(bool);
+  void setWaypointDb(WaypointDb *);
 
  signals:
-  void mapChanged();
+  void mapChanged(const int);
   void cacheClicked(const QString &);
   void detailClicked(const QString &);
   void showMessage(const QString &);
@@ -46,17 +51,22 @@ class MapWidget : public QGraphicsGeoMap {
   void toggleFullscreen();
   void gpsFollow();
   void showBubble(const Cache &);
+  void showBubble(const Waypoint &);
   void showDetails();
   void setBusy(bool);
   void addBanner(const QString &);
-  
+  void windowActivated(bool);
+
  private slots:
+  void reloadCustomWaypoints();
   void reloadTimerExpired();
   void reload();
   void zoomLevelChangedEvent(qreal);
   void centerChangedEvent(const QGeoCoordinate &);
   void positionUpdated(const QGeoPositionInfo &);
-  
+  void positionUpdated(const QCompassReading *);
+  void updateCaches();
+
  protected:
   void mousePressEvent(QGraphicsSceneMouseEvent *);
   void mouseReleaseEvent(QGraphicsSceneMouseEvent *);
@@ -74,6 +84,7 @@ class MapWidget : public QGraphicsGeoMap {
   class MapWaypointObject : public QGeoMapPixmapObject {
   public:
     MapWaypointObject(IconLoader *, const QString &, const Waypoint &);
+    bool contains( const QGeoCoordinate &) const;
     Waypoint waypoint() const;
   private:
     Waypoint m_wpt;
@@ -94,9 +105,11 @@ class MapWidget : public QGraphicsGeoMap {
   bool m_posIsValid;
   bool m_gpsLocked;
   bool m_hiRez;
+  bool m_hideOwn;
   int m_precisionAlpha;
   QString m_selectedCache;
   QList<Waypoint> m_selectedWaypoints;
+  qreal m_compass;
 
   // make sure map is only updated if it's dragged
   // significantly
@@ -106,6 +119,12 @@ class MapWidget : public QGraphicsGeoMap {
   QGeoMapCircleObject *m_gpsPrecision;
   QGeoMapGroupObject *m_cacheGroup;
   QGeoMappingManager *m_manager;
+
+  WaypointDb *m_wptDb;
+  QList<Waypoint> m_customWpts;
+
+  bool m_cacheListWasUpdated;
+  CacheList m_cacheList2Update;
 };
 
 #endif // MAP_WIDGET_H
