@@ -12,7 +12,7 @@
 <context>
     <name>CacheProvider</name>
     <message>
-        <location filename="../src/cacheprovider.cpp" line="379"/>
+        <location filename="../src/cacheprovider.cpp" line="381"/>
         <source>&amp;Cache Provider</source>
         <translation>&amp;Cache-Datenquelle</translation>
     </message>
@@ -68,77 +68,77 @@
 <context>
     <name>CoordinateTool</name>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="124"/>
+        <location filename="../src/coordinatetool.cpp" line="125"/>
         <source>New waypoint</source>
         <translation>Neuer Wegpunkt</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="135"/>
+        <location filename="../src/coordinatetool.cpp" line="136"/>
         <source>Name:</source>
         <translation>Name:</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="144"/>
+        <location filename="../src/coordinatetool.cpp" line="145"/>
         <source>Description:</source>
         <translation>Beschreibung:</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="169"/>
+        <location filename="../src/coordinatetool.cpp" line="170"/>
         <source>New Coordinate</source>
         <translation>Neue Koordinate</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="170"/>
+        <location filename="../src/coordinatetool.cpp" line="171"/>
         <source>Edit Coordinate</source>
         <translation>Koordinate bearbeiten</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="333"/>
+        <location filename="../src/coordinatetool.cpp" line="334"/>
         <source>S</source>
         <translation>S</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="334"/>
+        <location filename="../src/coordinatetool.cpp" line="335"/>
         <source>N</source>
         <translation>N</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="350"/>
+        <location filename="../src/coordinatetool.cpp" line="351"/>
         <source>W</source>
         <translation>W</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="351"/>
+        <location filename="../src/coordinatetool.cpp" line="352"/>
         <source>E</source>
         <translation>O</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="438"/>
+        <location filename="../src/coordinatetool.cpp" line="439"/>
         <source>New</source>
         <translation>Neu</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="441"/>
+        <location filename="../src/coordinatetool.cpp" line="442"/>
         <source>Edit</source>
         <translation>Bearbeiten</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="445"/>
+        <location filename="../src/coordinatetool.cpp" line="446"/>
         <source>Delete</source>
         <translation>Löschen</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="449"/>
+        <location filename="../src/coordinatetool.cpp" line="450"/>
         <source>Copy to clipboard</source>
         <translation>Kopiere in Zwischenablage</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="481"/>
+        <location filename="../src/coordinatetool.cpp" line="487"/>
         <source>Latitude</source>
         <translation>Breite</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="486"/>
+        <location filename="../src/coordinatetool.cpp" line="492"/>
         <source>Longitude</source>
         <translation>Länge</translation>
     </message>
@@ -146,7 +146,7 @@
 <context>
     <name>CustomWindow</name>
     <message>
-        <location filename="../src/customwindow.cpp" line="65"/>
+        <location filename="../src/customwindow.cpp" line="67"/>
         <source>Back</source>
         <translation>Zurück</translation>
     </message>
@@ -162,32 +162,32 @@
 <context>
     <name>GcBrowser</name>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="99"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="103"/>
         <source>No valid login specified, cache positions will be inaccurate!</source>
         <translation>Kein gültiger Login angegeben, Cache-Positionen werden ungenau sein!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="207"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="235"/>
         <source>!Network connection failed, please make sure you are connected to the internet and restart CacheMe!</source>
         <translation>!Netzwerkverbindung fehlgeschlagen. Bitte stellen Sie sicher, dass Sie mit dem Netzwerk verbunden sind und starten Sie CacheMe neu!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="247"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="275"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="297"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="325"/>
         <source>Login failed!</source>
         <translation>Einloggen fehlgeschlagen!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="449"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="478"/>
         <source>Unable to determine cache id!</source>
         <translation>Cache-ID nicht feststellbar!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="477"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="506"/>
         <source>Unable to determine cache guid!</source>
         <translation>Cache-Guid nicht feststellbar!</translation>
     </message>
@@ -285,7 +285,7 @@
 <context>
     <name>Gpx</name>
     <message>
-        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="72"/>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="73"/>
         <source>File %1 does not contain any geocaches</source>
         <translation>Die Datei %1 enthält keine Geocaches</translation>
     </message>
@@ -298,17 +298,17 @@
         <translation type="obsolete">Pocket-Queries (*.gox *.zip)</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="101"/>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="102"/>
         <source>Open Pocket Query (GPX, LOC or ZIP)</source>
         <translation>Pocket-Query öffnen (GPX, LOC oder ZIP)</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="102"/>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="103"/>
         <source>Pocket Queries (*.gpx *.loc *.zip)</source>
         <translation>Pocket-Queries (*.gpx *.loc *.zip)</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="111"/>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="112"/>
         <source>File %1 not found</source>
         <translation>Datei %1 nicht gefunden</translation>
     </message>
@@ -317,12 +317,12 @@
         <translation type="obsolete">Keine Caches in dieser Gegend</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="173"/>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="179"/>
         <source>Unable to get cache info</source>
         <translation>Kann Cache-Info nicht laden</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="189"/>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="195"/>
         <source>Unable to get cache detail</source>
         <translation>Kann Cache-Details nicht laden</translation>
     </message>
@@ -361,12 +361,12 @@
 <context>
     <name>LogWindow</name>
     <message>
-        <location filename="../src/logwindow.cpp" line="44"/>
+        <location filename="../src/logwindow.cpp" line="45"/>
         <source>Logs</source>
         <translation>Logs</translation>
     </message>
     <message>
-        <location filename="../src/logwindow.cpp" line="58"/>
+        <location filename="../src/logwindow.cpp" line="59"/>
         <source>Create new log</source>
         <translation>Neuen Log-Eintrag erstellen</translation>
     </message>
@@ -394,55 +394,60 @@
         <translation type="obsolete">&amp;Hilfe</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="24"/>
+        <location filename="../src/mainwindow.cpp" line="27"/>
         <source>&amp;Settings</source>
         <translation>&amp;Einstellungen</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="23"/>
+        <location filename="../src/mainwindow.cpp" line="26"/>
         <source>&amp;About</source>
         <translation>&amp;Über</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="38"/>
+        <location filename="../src/mainwindow.cpp" line="53"/>
+        <source>Help</source>
+        <translation>Hilfe</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="70"/>
         <source>About CacheMe</source>
         <translation>Über CacheMe</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="39"/>
-        <location filename="../src/mainwindow.cpp" line="53"/>
+        <location filename="../src/mainwindow.cpp" line="71"/>
+        <location filename="../src/mainwindow.cpp" line="86"/>
         <source>CacheMe</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="39"/>
+        <location filename="../src/mainwindow.cpp" line="71"/>
         <source>Version</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="40"/>
+        <location filename="../src/mainwindow.cpp" line="72"/>
         <source>Build date:</source>
         <translation>Erstellungsdatum:</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="41"/>
+        <location filename="../src/mainwindow.cpp" line="73"/>
         <source>(c) 2011 by Till Harbaum &lt;till@harbaum.org&gt;</source>
         <oldsource>(c) 2011 by Till Harbaum &lt;till@harbaum.org&gt;
 </oldsource>
         <translation>(c) 2011 von Till Harbaum &lt;till@harbaum.org&gt;</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="42"/>
+        <location filename="../src/mainwindow.cpp" line="74"/>
         <source>CacheMe is an online geocaching application.</source>
         <translation>CacheMe ist eine Online-Geocaching-Anwendung.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="146"/>
+        <location filename="../src/mainwindow.cpp" line="184"/>
         <source>This copy of CacheMe has expired and will close in one minute!</source>
         <translation>Diese Kopie von CacheMe ist abgelaufen und wird in einer Minute geschlossen!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="149"/>
+        <location filename="../src/mainwindow.cpp" line="187"/>
         <source>This copy of CacheMe will expire in %1 days!</source>
         <translation>Diese Kopie von CacheMe läuft in %1 Tagen aus!</translation>
     </message>
@@ -501,7 +506,7 @@
         <translation type="obsolete">Öffne &quot;%1&quot; im Browser ...</translation>
     </message>
     <message>
-        <location filename="../src/mapwidget.cpp" line="379"/>
+        <location filename="../src/mapwidget.cpp" line="425"/>
         <source>Displayed cache data is %1 weeks old!</source>
         <translation>Angezeigte Cache-Daten sind %1 Wochen alt!</translation>
     </message>
@@ -1257,7 +1262,7 @@
         <translation>&lt;unbekannt&gt;</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="171"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="200"/>
         <source>GPL version 2
 Copyright 2011 by Till Harbaum
 QSgml parts Copyright 2010 by Andreas Lehmann</source>
@@ -1266,7 +1271,7 @@ Copyright 2011 durch Till Harbaum
 QSgml-Teile Copyright 2010 durch Andreas Lehmann</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="45"/>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="46"/>
         <source>GPL version 2
 Copyright 2011 by Till Harbaum
 Quazip parts Copyright 2005 by Sergey A. Tachenov</source>
@@ -1326,66 +1331,129 @@ Quazip-Teile Copyright 2005 durch Sergey A. Tachenov</translation>
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="42"/>
+        <location filename="../src/settingsdialog.cpp" line="176"/>
         <source>Settings</source>
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <source>Map</source>
-        <translation type="obsolete">Karte</translation>
+        <location filename="../src/settingsdialog.cpp" line="88"/>
+        <source>Type</source>
+        <translation>Typ</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="66"/>
+        <location filename="../src/settingsdialog.cpp" line="82"/>
+        <source>Hybrid Map</source>
+        <translation>Hybridkarte</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="82"/>
+        <source>Transit Map</source>
+        <translation>ÖPNV-Karte</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="83"/>
+        <source>Gray Street Map</source>
+        <translation>Graue Straßenkarte</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="83"/>
+        <source>Mobile Street Map</source>
+        <translation>Mobile Straßenkarte</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="84"/>
+        <source>Mobile Terrain Map</source>
+        <translation>Mobile Geländekarte</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="84"/>
+        <source>Mobile Hybrid Map</source>
+        <translation>Mobile Hybridkarte</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="85"/>
+        <source>Mobile Transit Map</source>
+        <translation>Mobile ÖPNV-Karte</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="85"/>
+        <source>Mobile Gray Street Map</source>
+        <translation>Mobile graue Straßenkarte</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="107"/>
+        <source>Service</source>
+        <translation>Dienst</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="126"/>
+        <source>Bigger icons</source>
+        <translation>Große Icons</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="131"/>
+        <source>Hide owned/found</source>
+        <translation>Eigene/gefundene verstecken</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="182"/>
+        <source>Map</source>
+        <translation>Karte</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="183"/>
+        <source>Account</source>
+        <translation>Zugang</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="80"/>
         <source>Street Map</source>
         <translation>Straßenkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="66"/>
+        <location filename="../src/settingsdialog.cpp" line="80"/>
         <source>Satellite Map Day</source>
         <translation>Satellitenkarte Tag</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="67"/>
+        <location filename="../src/settingsdialog.cpp" line="81"/>
         <source>Satellite Map Night</source>
         <translation>Satellitenkarte Nacht</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="67"/>
+        <location filename="../src/settingsdialog.cpp" line="81"/>
         <source>Terrain Map</source>
         <translation>Geländekarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="70"/>
         <source>Map type</source>
-        <translation>Kartentyp</translation>
+        <translation type="obsolete">Kartentyp</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="86"/>
         <source>Map service</source>
-        <translation>Kartendienst</translation>
+        <translation type="obsolete">Kartendienst</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="98"/>
+        <location filename="../src/settingsdialog.cpp" line="120"/>
         <source>A change of the map service takes effect after restart.</source>
         <translation>Ein Wechsel des Kartendienstes wird erst nach einem Neustart aktiv.</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="107"/>
         <source>High density display</source>
-        <translation>Hoch auflösender Bildschirm</translation>
+        <translation type="obsolete">Hoch auflösender Bildschirm</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="117"/>
+        <location filename="../src/settingsdialog.cpp" line="149"/>
         <source>Geocaching.com account</source>
         <translation>Geocaching.com-Zugang</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="124"/>
+        <location filename="../src/settingsdialog.cpp" line="154"/>
         <source>Username</source>
         <translation>Benutzername</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="129"/>
+        <location filename="../src/settingsdialog.cpp" line="159"/>
         <source>Password</source>
         <translation>Passwort</translation>
     </message>
