@@ -169,10 +169,13 @@ int GcHtmlParser::parseMonth(const QString &str) {
 
   QString names[] = {
     "January", "February", "March", "April", "May", "June",
-    "July", "August", "October", "September", "November", "December"
+    "July", "August", "September", "October", "November", "December"
   };
 
   for(i=0;i<12 && names[i].compare(str, Qt::CaseInsensitive);i++);
+
+  qDebug() << __FUNCTION__ << "parsed" << str << "to" << i+1;
+
   return i+1;
 }
 
