@@ -11,6 +11,10 @@
 #include "attributewindow.h"
 #include "iconlabel.h"
 
+#ifdef FLICKCHARM
+#include "flickcharm.h"
+#endif
+
 AttributeWindow::AttributeWindow(const QList<Attribute> &attributes, 
 				 QWidget *parent) : 
   CustomWindow("AttributeWindow", parent),  
@@ -22,6 +26,10 @@ AttributeWindow::AttributeWindow(const QList<Attribute> &attributes,
   scrollArea->setWidgetResizable(true);
   scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
+#ifdef FLICKCHARM
+  new FlickCharm(scrollArea, this);
+#endif
+  
   QWidget *scrollWidget = new QWidget;
   QVBoxLayout *scrollvbox = new QVBoxLayout;
   scrollvbox->setContentsMargins(0,0,0,0);
