@@ -1,8 +1,7 @@
 /* external string MACRO handling is broken under symbian^1 */
-#ifdef S60V5
-#warning "Working around broken external symbian1 string macros!!"
+#ifdef Q_OS_SYMBIAN
 #define APPNAME "cacheme"
-#define VERSION "0.8.10"
+#define VERSION "0.8.11"
 #define DATADIR "/data/cacheme"
 #define LIBDIR "/data/cacheme"
 #ifdef EXPIRATION_DATE
