@@ -6,11 +6,18 @@
 #include <QGroupBox>
 #include <QLabel>
 #include <QScrollArea>
+#include <QPushButton>
+#include <QDesktopServices>
+#include <QUrl>
 
 #include "htmlview.h"
 #include "logwindow.h"
 #include "iconlabel.h"
 
+#ifdef FLICKCHARM
+#include "flickcharm.h"
+#endif
+
 class LogWidget : public QGroupBox {
 public:
   LogWidget(IconLoader *loader, const Log &log,
@@ -26,12 +33,14 @@ public:
 				    foundByMessage));
 
     layout->addWidget(new FixHtmlView(log.description(), this));
+    //    layout->addWidget(new HtmlLabel(log.description(), this));
     setLayout(layout);
   }
 };
 
-LogWindow::LogWindow(const QList<Log> &logs, QWidget *parent) : 
-  CustomWindow("LogWindow", parent),  m_logs(logs), m_iconLoader(24) {
+LogWindow::LogWindow(const QString &name, const QList<Log> &logs, 
+	     QWidget *parent) : CustomWindow("LogWindow", parent),
+	     m_logs(logs), m_iconLoader(24), m_name(name) {
 
   setWindowTitle(tr("Logs"));
 
@@ -39,17 +48,27 @@ LogWindow::LogWindow(const QList<Log> &logs, QWidget *parent) :
   scrollArea->setWidgetResizable(true);
   scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
+#ifdef FLICKCHARM
+  new FlickCharm(scrollArea, this);
+#endif
+
   QWidget *scrollWidget = new QWidget;
   QVBoxLayout *scrollvbox = new QVBoxLayout;
   scrollvbox->setContentsMargins(0,0,0,0);
 
-  foreach(Log log, logs)
-    scrollvbox->addWidget(new LogWidget(&m_iconLoader, log, this),0,0);
+  QPushButton *button = new QPushButton(tr("Create new log"));
+  connect(button, SIGNAL(clicked()), this, SLOT(openLogUrl()));
+  scrollvbox->addWidget(button,0,0);
+
+  foreach(Log log, logs) {
+    LogWidget *tlog = new LogWidget(&m_iconLoader, log, this);
+    scrollvbox->addWidget(tlog,0,0);
+  }
 
   scrollvbox->addStretch(1);
   scrollWidget->setLayout(scrollvbox);
   scrollArea->setWidget(scrollWidget);
-  
+
   setCentralWidget(scrollArea);
 }
 
@@ -57,3 +76,9 @@ LogWindow::~LogWindow() {
   qDebug() << __FUNCTION__;
 }
 
+void LogWindow::openLogUrl() {
+  qDebug() << __FUNCTION__;
+ 
+  QUrl url("http://www.geocaching.com/seek/log.aspx?wp=" + m_name);
+  QDesktopServices::openUrl(url);
+}
