@@ -25,7 +25,7 @@ void MapWidget::updateZoomButtons() {
 
 MapWidget::MapWidget(QGeoMappingManager *mgr) : 
   QGraphicsGeoMap(mgr), m_bubble(NULL), m_posIsValid(false), m_gpsMarker(NULL),
-  m_manager(mgr), m_wptDb(NULL) {
+  m_manager(mgr), m_wptDb(NULL), m_cacheListWasUpdated(false) {
   
   // try to get default from qsettings, otherwise start at berlin's zoo
   QSettings settings;
@@ -191,8 +191,9 @@ void MapWidget::showBubble(const Cache &cache) {
 
   hideBubble();
   m_bubble = new MapBubble(this, size().width() > size().height(), cache);
+  qDebug() << __FUNCTION__ << "A" << m_bubble << m_bubble->pixmap().size();
   addMapObject(m_bubble);
-
+  qDebug() << __FUNCTION__ << "B";
   this->m_mapOverlay->enableForwardButton(cache.url().isValid());
 }
 
@@ -358,9 +359,52 @@ bool MapWidget::MapWaypointObject::contains(const QGeoCoordinate &coo) const {
   return boundingBox().contains(coo);
 }
 
+#include <QGraphicsScene>
+#include <QGraphicsView>
+
+void MapWidget::updateCaches() {
+  // are there pending cachelist updates?
+  if(m_cacheListWasUpdated) {
+    qDebug() << __FUNCTION__ << "replaying update";
+    updateCaches(m_cacheList2Update);
+    m_cacheListWasUpdated = false;
+    m_cacheList2Update.clear();
+  }
+}
+
+void MapWidget::windowActivated(bool activated) {
+  if(activated) {
+    qDebug() << __FUNCTION__;
+
+    // emit one shot timer
+    QTimer::singleShot(200, this, SLOT(updateCaches()));
+  }
+}
+
 void MapWidget::updateCaches(const CacheList &cacheList) {
   static bool tooOld = false;
 
+  // try to get access to parent window
+  bool windowIsActive = false;
+
+  if(this->scene()) 
+    if(this->scene()->views().size() == 1) 
+      if(this->scene()->views()[0]) 
+	if(this->scene()->views()[0]->window()) 
+	  windowIsActive = 
+	    this->scene()->views()[0]->window()->isActiveWindow();
+
+  if(!windowIsActive) {
+    qDebug() << __FUNCTION__ << "delaying update";
+    m_cacheListWasUpdated = true;
+    m_cacheList2Update = cacheList;
+    return;
+  }
+
+  //  qDebug() << __FUNCTION__ << this->window();
+  //  if(this->window())
+  //    qDebug() << __FUNCTION__ << this->window()->hasFocus();
+
   // save cache if existing bubble
   Cache bubbleCache;
   Waypoint bubbleWaypoint;
